@@ -236,7 +236,7 @@ ev_page_cache_set_page_label (EvPageCache *page_cache,
 	g_return_val_if_fail (page_label != NULL, FALSE);
 
 	/* First, look for a literal label match */
-	for (i = 0; i < page_cache->n_pages && page_cache->has_labels; i ++) {
+	for (i = 0; i < page_cache->n_pages; i ++) {
 		if (page_cache->page_labels[i] != NULL &&
 		    ! strcmp (page_label, page_cache->page_labels[i])) {
 			ev_page_cache_set_current_page (page_cache, i);
@@ -308,9 +308,9 @@ ev_page_cache_get_size (EvPageCache *page_cache,
 	}
 
 	if (width)
-		*width = (*width) * scale;
+		*width = (int) ((*width) * scale + 0.5);
 	if (width)
-		*height = (*height) * scale;
+		*height = (int) ((*height) * scale + 0.5);
 
 }
 
