@@ -254,8 +254,8 @@ pdf_document_render_pixbuf (EvDocument   *document,
 						  page);
 
 	poppler_page_get_size (poppler_page, &width_points, &height_points);
-	width = (int) ceil (width_points * scale);
-	height = (int) ceil (height_points * scale);
+	width = (int) ((width_points * scale) + 0.5);
+	height = (int) ((height_points * scale) + 0.5);
 
 	pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
 				 FALSE, 8,
@@ -868,14 +868,14 @@ pdf_document_find_iface_init (EvDocumentFindIface *iface)
 }
 
 static void
-pdf_document_ps_exporter_begin (EvPSExporter *exporter, const char *filename)
+pdf_document_ps_exporter_begin (EvPSExporter *exporter, const char *filename,
+				int first_page, int last_page)
 {
 	PdfDocument *pdf_document = PDF_DOCUMENT (exporter);
-	int n_pages;
 	
-	n_pages = pdf_document_get_n_pages (EV_DOCUMENT (exporter));
-	pdf_document->ps_file = poppler_ps_file_new (pdf_document->document,
-						     filename, n_pages);
+	pdf_document->ps_file = poppler_ps_file_new (pdf_document->document, filename,
+						     first_page,
+						     last_page - first_page + 1);
 }
 
 static void
