@@ -53,9 +53,12 @@ struct _EvWindowClass {
 GType		ev_window_get_type	(void);
 void		ev_window_open		(EvWindow       *ev_window,
 					 const char     *uri);
-void		ev_window_open_page	(EvWindow       *ev_window,
-					 int             page);
+void		ev_window_open_page_label	(EvWindow       *ev_window,
+						 const char *label);
 gboolean	ev_window_is_empty	(const EvWindow *ev_window);
+void		ev_window_print_range   (EvWindow       *ev_window,
+					 int             first_page,
+					 int		 last_page);
 
 G_END_DECLS
 
