@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: main.c,v 1.11 2005/04/09 11:26:38 chpe Exp $
+ *  $Id: main.c,v 1.13 2005/05/18 03:17:38 jrb Exp $
  */
 
 #include "config.h"
@@ -32,9 +32,13 @@
 #include "ev-stock-icons.h"
 #include "ev-debug.h"
 #include "ev-job-queue.h"
+#include "ev-file-helpers.h"
+
+static char *page_label;
 
 static struct poptOption popt_options[] =
 {
+	{ "page-label", 'p', POPT_ARG_STRING, &page_label, 0, N_("The page of the document to display."), N_("PAGE")},
 	{ NULL, 0, 0, NULL, 0, NULL, NULL }
 };
 
@@ -58,9 +62,14 @@ load_files (const char **files)
 		window = GTK_WIDGET (ev_application_new_window (EV_APP));
 		gtk_widget_show (window);
 		ev_window_open (EV_WINDOW (window), uri);
+		
+		if (page_label != NULL)
+			ev_window_open_page_label (EV_WINDOW (window), page_label);
 
 		g_free (uri);
         }
+
+	g_free (page_label);
 }
 
 int
@@ -87,6 +96,7 @@ main (int argc, char *argv[])
 	ev_job_queue_init ();
 	g_set_application_name (_("Evince Document Viewer"));
 
+	ev_file_helpers_init ();
 	ev_debug_init ();
 	ev_stock_icons_init ();
 	gtk_window_set_default_icon_name ("postscript-viewer");
@@ -102,6 +112,7 @@ main (int argc, char *argv[])
 
 	gnome_accelerators_sync ();
 	poptFreeContext (context);
+	ev_file_helpers_shutdown ();
 
 	return 0;
 }
